Class: SkypeValidator
- Inherits:
-
AccountNameValidator
- Object
- ActiveModel::EachValidator
- AccountNameValidator
- SkypeValidator
- Defined in:
- lib/skype_validator.rb
Overview
Validates Skype screen names. From the Skype website:
> It must be between 6-32 characters, start with a letter and contain only > letters and numbers (no spaces or special characters).
The following error message keys are used to localize invalid screen names.
| | | |:—————————|:—————————————-| | ‘skype_too_short` | Skype name is less than 6 characters. | | `skype_too_long` | Skype name is over 32 characters. | | `skype_invalid_chars` | Skype name contains invalid characters. | | `skype_invalid_first_char` | Skype name doesn’t start with a letter. |
Options
| | | |:————-|:————————————————-| | ‘:message` | A custom message to use if the email is invalid. | | `:allow_nil` | If true, `nil` values are allowed. |
Method Summary
Methods inherited from AccountNameValidator
add_validation, error_key_prefix, first_char, max_length, min_length, valid_chars, #validate_each