Class: SteamValidator

Inherits:
AccountNameValidator show all
Defined in:
lib/steam_validator.rb

Overview

Validates steam account IDs. Steam IDs are between 3 and 63 characters long and consist of letters, numbers, or underscores.

The following error message keys are used to localize invalid screen names.

| | | |:———————-|:————————————–| | ‘steam_too_short` | Steam ID is less than 6 characters. | | `steam_too_long` | Steam ID is over 32 characters. | | `steam_invalid_chars` | Steam ID contains invalid characters. |

Options


| | | |:————-|:————————————————-| | ‘:message` | A custom message to use if the email is invalid. | | `:allow_nil` | If true, `nil` values are allowed. |

Examples:

validates :steam_id, steam: true

Method Summary

Methods inherited from AccountNameValidator

add_validation, error_key_prefix, first_char, max_length, min_length, valid_chars, #validate_each